#
# spec file for package ladspa-caps
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ladspa-caps
Version:        0.9.26
Release:        1.13
Summary:        LADSPA caps plugins
License:        GPL-3.0-or-later
URL:            http://quitte.de/dsp/
Source:         http://quitte.de/dsp/caps_%{version}.tar.bz2
# PATCH-FIX-UPSTREAM bmwiedemann -- ToDo
Patch2:         reproducible.patch
BuildRequires:  gcc-c++
Supplements:    ladspa

%description
This package provides a LADSPA (Linux Audio Developer's Simple Plug-in API)
caps plugins, the C* Audio Plugin Suite including instrument amplifier
emulation, stomp-box classics, versatile virtual analog oscillators,
fractal oscillation, reverb, equalization and others.

%prep
%setup -q -n caps-%{version}
%patch2 -p1

%build
make %{?_smp_mflags} CFLAGS="%{optflags} -ggdb -fPIC"

%install
mkdir -p %{buildroot}%{_libdir}/ladspa
install -c *.so %{buildroot}%{_libdir}/ladspa

%files
%license COPYING
%doc README CHANGES
%{_libdir}/ladspa

%changelog
* Sun Nov  3 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.26:
  * documentation updates
  * DDDelay removed, needs more work
  version 0.9.25:
  * potential gcc overoptimisation resulting in NaN in Kaiser
    window setup eliminated (fix contributed by Jean Pierre
    Cimalando)
  * updated to reflect changes to the div() and pow10f()
    functions in libc
  * tonestack coefficient update reverted to original Yeh
    implementation
  * Compress default measurement mode switched to RMS, attack
    range doubled
  * Compress power and gain filter cutoff lowered to lessen
    intermodulation distortion
  * Plate defaults changed
  * volume control added to Spice hi and lo circuits, max gain
    reduced on both
  * Wider output channels swapped
  * AutoFilter rate lowered
  * Scape parameters cleaned up and remapped, tune control
    removed
  * Noisegate hysteresis increased to 180 ms
  * dc-30 tonestack R3 20k -> 10k
  * Eq10 Q changed to render optimally flat response at all zero
    band gain settings
  * div port added to Click
  * new plugin DDDelay
  version 0.9.24:
  * documentation updates including switch to 48k for all spectra
  * "twin" and "stanford" tonestack models swap places
  * ChorusI feedback changed to interpolation, softens zipper
    noise on t changes
  * use vestigial FPTruncateMode only on pre-SSE2 hardware
  * 4x128 oversampling option removed from Compress plugins
  * state port displaying current gain reduction on Compress
    plugins
  * _latency port for parallel Eq
  * Saturate fade-in bug eliminated
  * Noisegate hysteresis interval lengthened
  * Click sounds "stick" brightened and "beep" shortened
  * run_adding() removed, reducing binary size by 30 %% and
    compile time similarly
  * JVRev tail modified, low-passed
  * all ports reordered to consistent ctrl i/o audio i/o order
  * Eq4p crossfade reimplemented as equal-power squared cosine,
    smoother now
  * EqFA4p added
  * non-SSE v4f_shuffle surrogate fixed
    (fixes Eq4p on ARM, reported by Jens Dreske)
  * dropped 44.1 kHz ToneStackLT
  * OnePole header renamed IIR1, filters renamed LP1 and HP1
  * BiQuad header and filter renamed IIR2, SIMD *4f filters
    renamed *v4
  * CabinetIII (less demanding loudspeaker emulation resurrected
    again)
  * ChorusI port ranges and defaults adjusted
  * Compress parameter mappings and defaults adjusted
  version 0.9.23:
  * ChorusI hp filter denormal protection added
  version 0.9.22:
  * ChorusI blend behaviour changed
  * ChorusI parameters adjusted
  * ChorusI hp filter before delay added
  * AutoFilter parameters adjusted
  * AutoFilter 'range' port becomes 'depth'
  version 0.9.21:
  * Eq10 Q increased
  * AmpVTS bright/compression/gain mappings adjusted
  * AutoFilter reverted to 0.9.1 version with adjusted parameters
  version 0.9.20:
  * ToneStack ports rearranged (following "control before audio"
    convention)
  * ToneStack LT model selection fixed
  version 0.9.19:
  * Noisegate partially rewritten, defaults adjusted
  * Noisegate bug causing spurious gain fluctuations in closed
    state eliminated
  * AmpVTS compression controls adjusted
  * influence of total gain on compression in AmpVTS reduced
  * documentation polish
  version 0.9.18:
  * restored ToneStack presets to present the full list
  * AmpVTS 'bright' filter given slight resonance
  * AmpVTS compression control range widened
  version 0.9.17:
  * multiple inclusion header guards changed to comply with
    ISO/IEC 9899:2011 (at the insistence of Markus Elfring)
  * PlateX2 fixed to read correct port for damping parameter
    (reported by James Morris)
  * uninstall removes rdf
  * DSP::FIR4f::set_kernel size overflow in default parameter
    fixed (reported and isolated by Ricardo Crudo)
  * AmpVTS "lowcut" filter changed from 2- to 1-pole
  * "HK 20" tonestack renamed to "AK 20"
  * AmpVTS lowcut mapping changed, default lowered
  * AmpVTS highpass 1 cutoff raised
  * lowpass filter added to Noisegate's opening peak detector
  * Noisegate not NoiseGate
  * Click normal addition limited to idle loop
  * NoiseGate logic loop bug fixed, hysteresis added
  * documentation polish
  version 0.9.16:
  * NoiseGate simplified, sped up, gain lowpassed, click bug
    eliminated
  * Sin smoothened, defaults updated
  * PhaserII defaults updated
  * Fractal defaults updated
  * documentation polish
  version 0.9.15:
  * no-vector-arithmetic compilation fixed
  version 0.9.14:
  * AutoFilter x/y parameter eliminated
  * Fractal hp changed to be configurable, attractors
    recalibrated
  * DSP::Lorenz instantly initialises to useful state
  * documentation polish
  version 0.9.13:
  * Eq4p softens drastic parameter changes by crossfading static
    filters
  * Eq4p employing single v4f filter, slightly quicker
  * Eq4p 'off' filter mode
  * documentation and interface polish
  version 0.9.12:
  * non-SSE compilation fixed
  version 0.9.11:
  * DSP::Roessler instantly initialises to useful state
  * Logarithmic port bounds and values fixed to reflect actual
    intent, affecting Spice, AutoFilter and ChorusI
  * clicking automatic gain fade on activate() eliminated in
    Saturate
  * Dirac merged into Click
  * Lorenz and Roessler merged into Fractal
  * JVRev removed
  * running plugins for zero frames returns without touching
    state
  * CabinetII and III removed
  * PhaserII sine LFO and LFO choice port added
  * PhaserII fractal modulation extensively revised
  * ChorusI rate lower bound slightly increased
  * ChorusI delay line length adjusted to accommodate full
    t+width range
  * all Chorus and Phaser plugins removed save for ChorusI and
    PhaserII
  * major documentation revision
  * Eq4p parametric equaliser plugin
  * RBJ shelving filter prototype implementation fixed
  * "2x2" stereo plugin label postfix changed to "X2"
  * Eq renamed Eq10
  * SIMD implementation updates
  * DSP::RBJ coefficient calculation rearranged
  * Click bpm range changed, default lowered substantially
  version 0.9.10:
  * DSP::RMS protected against negative sum of squares
  * documentation updates
  version 0.9.8:
  * Spice enabled by default, Spice2x2 added
  * AmpVTS default oversampling ratio changed to 4x
  * JVRev refinements
  * Cabinet gain upper limit reinstated to 24 dB
  * AutoFilter modulation slightly adjusted
  * more *ChorusII modulation smoothness
  * 1st-order IIR lp set_f fix part 2
  * 1st-order IIR lp set_f fix part 1
  * 1st order low-pass for AutoFilter modulation LFO
  * DelayTapA removed
  * README updated
  * Click 'stick' sound brightened
  * moved processor_specific_denormal_measures() to activate(),
    speedup
  version 0.9.7:
  * ChorusI is back
  * AutoFilter modulation range and default parameter updates
  version 0.9.6:
  * Click fixed to compile by older g++ versions
  version 0.9.5:
  * AmpVTS model port moved, renamed to the more apt 'tonestack'
  * documentation refinements
  * appreciable AmpVTS speedup by going back to sample_t for
    accumulator
  * NoiseRatio attack time control
  * sample rate dependencies in NoiseGate removed, time
    constants revised
  * Tonestacks reordered
  * Plugin::over_fs
  * AmpVTS model setting fixed to follow the correct input
  * CabinetIII resurrected
  * AmpVTS 'ratio' port renamed to 'over'
  * more filters for AutoFilter, ladder stage gain control
  * AutoFilter oversampling
  * AmpVTS bias in poweramp, dcblock before output
  * AutoFilter envelope calculation fixed for fs > 153.6 kHz
  * peak/rms selection for Compress
  * AmpVTS tuning
  version 0.9.4:
  * AmpVTS bright mapping revised
  * Compress hi-pass removed
  * Compress saturation changed from tanh to atan
  * beep wave for Click
  * selectable oversampling ratio for Compress in saturating
    mode
  * fixed Compress to apply gain before saturation
  * replaced sample_func_t with the more apt yield_func_t
  * minor cosmetics
  * caps-doc is a separate package
  * selectable wave for Click, parfiltmodel added
  * further smoothened ChorusII modulation
  * selectable oversampling ratio for Amp
  * moved some compress setup calls from Amp's run() to
    activate()
  * rdf target prerequisite for dist
  * Eq Q fixed, flat response at 0 gain
  version 0.9.3:
  * Smoother modulation for ChorusII
  * AmpVTS filters retuned
  * correction for ToneStack gain in AmpVTS
  * ToneStack models reordered, 'wookie', 'porky', 'HK 20',
    'nihon ace' models added
  * Amp 'bias' now a filtered function of output power, control
    removed
  * division operation in 1st-order hipass setup replaced by
    multiplication
  * Saturate gain = 0 dB in 'bypass' mode
  * Saturate 'rectify' mode
  * AmpVTS, Plate control mapping adjusted
  version 0.9.2:
  * included dsp/polynomials.cc in the tarball
  version 0.9.1:
  * Lorenz/Roessler rate linked to fs
  * AutoFilter replaces SweepVFI
  * CabinetIV
  * fixed erroneous float promotion of upsampler z padding
    parameter
  * lots of parameter tuning
  * many cleanuppies here and there
  * SweepVFI/AutoFilter saturating SVFII ladder (instead of
    oversampled SVFI)
  * UniqueIDs moved into interface.cc
  * SweepVFI modulation comes as range + x/z now
  * GPL v3
  * more Phaser notches
  * LR filters for Spice
  * Saturate inverse gain for approximately constant loudness
  * Scape extensively reworked
  * further refinements to Chorus and Phaser units for smoother
    modulation
  * SweepVFII removed
  * LADSPA_PORT_GROUP
  * Compress* input gain removed
  * ToneStackLT rolled into ToneStack and eliminated
  * fixed w miscalculation in DSP::Sine::set_f with fs given
  * AmpPlus/AmpVTS total rewrite
  * TubeCompress merged into Compress, for great template
    goodness
  * *Chorus* modulation rate decoupled from samplerate
  * tanh approximation, available in the Saturate plugin
  * *Chorus* units reworked for smoother modulation and sound
  * StereoChorusII2x2 plugin
  * JVRev bandwidth filter/control added
  * VCO* removed
  * HRTF removed
  * ChorusI, StereoChorusI, PhaserI removed
  * CabinetI removed
  * No more AmpStub silliness
  * All Amp and Preamp plugins removed, save for AmpVTS
  * Incite rechristened Spice
  * JVRev blend range normalised to [0..1]
  * Plate input value ranges adjusted to uniform [0..1]
  * Phaser* spread value range upper bound adjusted to 1 from pi
    multiples
  version 0.9.0:
  * White bleached (was slightly pinkish before)
  * up+down oversampling functionality rolled into one class
  * Incite plugin
  * total redesign of the Clip plugin, renamed to Saturate
  * NoiseGate plugin
  * RBJ prototypes changed to accept biquad instead of coeff.
    arrays
  * various default value changes
  * all FIRs changed to use templated kernel size, appreciable
    speedup for all oversampled plugins
  * reduced the number of arithmetic operations in the tonestack
    coefficient update function, speedup for ToneStack and
    AmpVTS
  * TubeCompress2x2 plugin
  * TubeCompress plugin
  * no more borrowed kernels!
  * CabinetII gain adjusted for Mesa and Pro Jr models (much
    lower now and more in line with the other models)
  * Amp final drive gain reduced slightly to prevent foldover
    distortion
  * SweepVF fractal rate control mapping adjusted
  * Pan completely redesigned with Orban-like stereo image
    synthesis
  * Narrower mode switch and mid/side operation added
  * Plate parameter ranges modified for a brighter and less
    reverberant default sound
  * VCOd sync option had to be dropped due to compiler
    incompatibility
  * Lorenz, Roessler fitted with a dc-blocking filter
  * all int sample loop variables changed to unsigned, slightest
    speedup
  * Compress2x2 plugin
  * Compress plugin replaced with a completely new design
  * Phaser feedback port ranges sanitised
  * StereoPhaser plugins
  * PhaserII gain reduced by 6dB
  * "latency" outputs of all plugins removed
  * Descriptor array handling changed to disable individual
    plugins with relative ease
  * fixed instances of g++ -O3 and above compiled code
    segfaulting, performance gained everywhere
  * documentation reworked extensively
  * CEO wave is resampled at runtime from fs = 8kHz source
  * CEO mantra changed (now an flite recording)
  * Click changed to use modal synthesis to generate the click
    wavetable, for improved sound and independency of sample
    rate
  * Plate changed to do delay summation using doubles
  * 1st and 2nd order filters changed to use templated types for
    coefficient and state storage
  * 1st order input hipass added to AmpVTS plugin
  * filter 'mode' port added to AutoWah, and renamed to
    AutoFilter
  * fixed improper 'model' labels meant to be 'mode' in the rdf
    generator
  version 0.4.5:
  * Narrower plugin added
  * fixed 'configure.py' to work with python3
  * fixed Sin, Roessler and Lorenz gain smoothing on activation
- Dropped caps-fix-double-free.diff (no longer applicable)
- Refreshed reproducible.patch
- Spec cleanup
* Mon May 22 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build more reproducible
* Mon Mar  3 2014 tiwai@suse.de
- Remove obsoleted autoreq/autoprov tags
* Sat Mar  1 2014 andreas.stieger@gmx.de
- use verbatim upstream tarball
- add source URLs, see https://en.opensuse.org/SourceUrls
* Wed Feb 26 2014 tiwai@suse.de
- correct the license to GPL-2.0+
* Mon Dec 16 2013 tiwai@suse.de
- Initial version 0.4.4: split from ladspa package
- Patch carried from the original ladspa package
  caps-fix-double-free.diff
